@@ -22,6 +22,8 @@ import inspect
 import io
 import ipaddress
 import numbers
+import os
+import sys
 import typing
 import uuid
 from types import FunctionType
@@ -310,6 +312,12 @@ _global_type_lookup[type] = st.sampled_from(
     [type(None)] + sorted(_global_type_lookup, key=str)
 )
 
+if sys.version_info[:2] >= (3, 9):  # pragma: no cover
+    # subclass of MutableMapping, and in Python 3.9 we resolve to a union
+    # which includes this... but we don't actually ever want to build one.
+    _global_type_lookup[os._Environ] = st.just(os.environ)
+
+
 try:  # pragma: no cover
     import numpy as np
     from hypothesis.extra.numpy import arrays, array_shapes, scalar_dtypes, array_dtypes
@@ -412,7 +420,7 @@ def register(type_, fallback=None):
 
 @register("Type")
 def resolve_Type(thing):
-    if thing.__args__ is None:
+    if getattr(thing, "__args__", None) is None:
         return st.just(type)
     args = (thing.__args__[0],)
     if getattr(args[0], "__origin__", None) is typing.Union:
